@@ -9,7 +9,7 @@ from ...profiles.models import Profile
 User = get_user_model()
 
 
-class UserTestCase(UserTestCase):
+class GroupTestCase(UserTestCase):
     def test_add_profile_to_group_updates_rev(self):
         user = self._get_new_user()
 
@@ -29,10 +29,24 @@ class UserTestCase(UserTestCase):
 
     def test_user_creation_adds_default_groups(self):
         group_name = self._get_random_string()
+        default_user_group_names = [group_name]
 
-        with self.settings(DJANGO_SSO_APP_DEFAULT_USER_GROUPS=[group_name]):
+        with self.settings(DJANGO_SSO_APP_DEFAULT_USER_GROUPS=default_user_group_names):
             user = self._get_new_user()
 
             user_groups = user.groups.values_list('name', flat=True)
 
             assert group_name in user_groups
+
+    def test_user_profile_creation_adds_default_groups(self):
+        group_name = self._get_random_string()
+        default_profile_group_names = [group_name]
+
+        with self.settings(DJANGO_SSO_APP_DEFAULT_PROFILE_GROUPS=default_profile_group_names):
+            user = self._get_new_user()
+
+            user_groups = user.sso_app_profile.groups.values_list('name', flat=True)
+
+            print('GROP NAMES', user_groups, group_name)
+
+            assert group_name in user_groups
