@@ -104,9 +104,14 @@ class TestProfileUpdate(UserTestCase):
 
             if f == 'birthdate':
                 model_val = str(model_val)
+            elif f == 'expiration_date':
+                model_val = model_val.isoformat()
             elif f == 'country':
                 object_val = object_val.upper()
                 model_val = str(model_val).upper()
+            elif f == 'country_of_birth':
+                object_val = object_val.upper()
+                model_val = str(model_val).upper()
 
             self.assertEqual(model_val, object_val)
 
