@@ -44,7 +44,8 @@ DJANGO_SSO_APP_BASE_DJANGO_APPS = [
     'django_sso_app.core.apps.devices',
     'django_sso_app.core.apps.services',
     'django_sso_app.core.apps.api_gateway',
-    'django_sso_app.core.apps.passepartout'
+    'django_sso_app.core.apps.passepartout',
+    'django_sso_app.core.apps.events'
 ]
 
 DJANGO_SSO_APP_DJANGO_APPS = [
